#!/bin/bash

#loop count (a loop is forward and reverse)
loopCount=3

#timeLapse
timeLapse=0.4

#set the PATH to include /usr/local/bin
if test "$PATH" = "${PATH//\/usr\/local\/bin}"; then
  export PATH=/usr/local/bin:$PATH
fi

#arg 1 is path to input file
inputFile="${1}"

#set file extension as desired (e.g. ".mov")
fileExt=".mp4"

inputFileBase="${inputFile//.m??}"

#arg 2 is path to input file
outputFile="${2}"

#arg 3 is overlay file path
overlayFile="${3}"

#0. may need to encode to specs first

#1. remove audio (and downconvert video)
workFile1="${inputFileBase}.noAudio${fileExt}"
ffmpeg -i "${inputFile}" -pix_fmt yuv420p -preset superfast -r 30 -crf 28 -s 1280x720 -c:v libx264 -an -y "${workFile1}"

#2. time lapse
workFile2="${inputFileBase}.timeLapse${fileExt}"
ffmpeg -i "${workFile1}" -filter_complex "[0:v]setpts=${timeLapse:-0.25}*PTS[v]" -map "[v]" -y "${workFile2}"

#3. make it square
#ffmpeg -i /Users/steve/Desktop/TriggerDemo.mov -filter:v "crop=720:720:280:0" /Users/steve/Desktop/TriggerDemoCropped.mov
workFile3="${inputFileBase}.square${fileExt}"
ffmpeg -i "${workFile2}" -filter:v "crop=720:720:280:0" -y "${workFile3}"

#4. overlay
if test -r "${overlayFile}"; then
workFile4="${inputFileBase}.overlay${fileExt}"
ffmpeg -i "${workFile3}" -i "${overlayFile}" -filter_complex "[0:v]overlay=0:0[v]" -map "[v]" -y "${workFile4}"
else
workFile4="${workFile3}"
fi


#5.reverse
workFile5="${inputFileBase}.reverse${fileExt}"
ffmpeg -i "${workFile4}" -filter_complex "[0:v]reverse[v]" -map "[v]" -y "${workFile5}"

#6. concat it n-times
#fwd1-rev1-fwd2-rev2-fwd3-rev3…fwdN-revN
workFile6="${inputFileBase}.looper${fileExt}"
if((loopCount > 0)); then
  ffmpeg -f concat -safe 0 -i <(for (( ((i=0)) ; ((i<loopCount)) ; ((i++)) )) ; do printf "file %s\n" "${workFile4}" "${workFile5}" ; done) -c copy -y "${workFile6}"
else
  workFile6="${workFile4}"
fi

# move product to output path
cp "${workFile6}" "${outputFile}"

rm -rf "${workFile1}"
rm -rf "${workFile2}"
rm -rf "${workFile3}"
rm -rf "${workFile4}"
rm -rf "${workFile5}"
rm -rf "${workFile6}"
rm -rf "${workFile7}"

